pub struct HistogramConfig { /* private fields */ }Expand description
Implementations
Sourceimpl HistogramConfig
impl HistogramConfig
Sourcepub fn new(sig_fig: SigFig, percentiles: Vec<f64>) -> MetricResult<Self>
pub fn new(sig_fig: SigFig, percentiles: Vec<f64>) -> MetricResult<Self>
Creates a new histogram configuration with the given significant figures and percentiles.
Errors
Returns an error if any percentile is NaN/inf or outside [0.0, 1.0).
Sourcepub fn with_base_metrics(
self,
emit_base_metrics: impl IntoIterator<Item = HistogramBaseMetric>,
) -> Self
pub fn with_base_metrics( self, emit_base_metrics: impl IntoIterator<Item = HistogramBaseMetric>, ) -> Self
Replaces the set of emitted base histogram metrics.
Sourcepub const fn with_count(self, emit: bool) -> Self
pub const fn with_count(self, emit: bool) -> Self
Enables or disables the .count histogram metric.
Sourcepub const fn with_avg(self, emit: bool) -> Self
pub const fn with_avg(self, emit: bool) -> Self
Enables or disables the .avg histogram metric.
Note: .avg currently reflects p50 behavior for compatibility.
Sourcepub fn with_bounds(self, min: u64, max: u64) -> MetricResult<Self>
pub fn with_bounds(self, min: u64, max: u64) -> MetricResult<Self>
Sets histogram recording bounds.
These bounds determine the compatible pool and the histogram allocation shape.
Errors
Returns an error if min < 1 or max < min.